@@ -47,21 +47,28 @@ class Peak:
         """Get the axis keys"""
         return self.axis_property.axis_keys()
 
+    def axis_dimensions(self):
+        """Get the axis dimensions"""
+        return self.axis_property.get_field(name='dimension')
+
+    def axis2dimension(self, axis):
+        """Convert an axis (e.g. 'HN') to a dimension (e.g. 'X')"""
+        try:
+            return self.axis_property.get_field(name='dimension', axis=axis)[0]
+        except KeyError as e:
+            raise KeyError(e)
+
     def num_dims(self):
         """Number of dimensions"""
         return len(self.axis_keys())
 
-    def axis_labels(self):
-        """Get the axis labels"""
-        return self.axis_property.axis_labels()
-
-    def get_par(self, par, axis_keys='all'):
+    def get_par(self, par, axis_dimensions='all'):
         """
         Get value of specified parameter for specified axes.
 
         :param par: nmrPipe peak table parameter name (e.g. *_PPM, HEIGHT)
                     The * is substituted with axis values for each label requested
-        :param axis_keys: list of axis identifiers to include (e.g. 'X' or default of 'all')
+        :param axis_dimensions: list of axis identifiers to include (e.g. 'X' or default of 'all')
         :return: singleton value or list of values
         """
         if '*' not in par:
@@ -70,14 +77,14 @@ class Peak:
             par_set = []
 
             # determine which axes to query
-            if axis_keys == 'all':
-                axis_keys = self.axis_property.axis_keys()
-            if isinstance(axis_keys, str):
-                axis_keys = [axis_keys]
+            if axis_dimensions == 'all':
+                axis_dimensions = self.axis_dimensions()
+            if isinstance(axis_dimensions, str):
+                axis_dimensions = [axis_dimensions]
 
             # perform substitutions of axis names into parameter name as needed
-            for axis in axis_keys:
-                if axis not in self.axis_property.axis_keys():
+            for axis in axis_dimensions:
+                if axis not in self.axis_dimensions():
                     raise KeyError(f'invalid axis: {axis}')
                 par_set.append(par.replace('*', axis))
 
@@ -121,12 +128,13 @@ class Peak:
         if not isinstance(roi, ROI):
             raise TypeError('region of interest must be provided as ROI class object')
 
-        if roi.axis_labels() != self.axis_property.axis_labels():
+        if roi.axis_keys() != self.axis_property.axis_keys():
             raise ValueError('the current peak and the given ROI do not have same set of axes')
 
         for axis in self.axis_keys():
+            dimension = self.axis2dimension(axis)
             roi_range = roi.get_field(name='roi', axis=axis)[0]
-            peak_ppm = self.get_par(f'{axis}_PPM')
+            peak_ppm = self.get_par(f'{dimension}_PPM')
             if not roi_range.contains(peak_ppm):
                 return False
         return True
@@ -140,14 +148,14 @@ class Peak:
 
         # TODO:
         #  the Mask.axis_labels property is np.ndarray, so "==" is done pairwise and we need .all()
-        #  maybe upgrade Mask class to use axis_labels() method that returns a list?
-        if not (mask.axis_labels == self.axis_labels()).all():
+        #  maybe upgrade Mask class to use AxisData and then call axis_keys() method here
+        if not (mask.axis_labels == self.axis_keys()).all():
             raise ValueError('mask and peak have different axes')
 
         try:
             return mask.ppm_in_mask(
                 peak_ppm=self.get_par('*_PPM'),
-                peak_axis_labels=self.axis_labels(),
+                peak_axis_property=self.axis_property,
                 box_radius=box_radius,
             )
         except PeakOutsideOfMaskError as e:
@@ -264,33 +272,29 @@ class PeakTable:
                 raise KeyError(e)
 
         elif isinstance(carrier_frequency, AxisData):
-            if carrier_frequency.axis_labels() != self.axis_property.axis_labels():
+            if carrier_frequency.axis_keys() != self.axis_keys():
                 raise AttributeError('The axes for the given carrier frequency data dot match those of the peak table')
             # extract ONLY the carrier frequency values from the carrier_frequency AxisData object
             # this object could contain other properties that we don't want
             self.axis_property.set_data(carrier_frequency.get('carrier_frequency'))
 
         else:
-            msg = 'define carrier frequency by providing a list of lists: [key, label, cf, cf_units]'
+            msg = 'define carrier frequency by providing a list of lists: [key, cf, cf_units]'
             if not is_iterable(carrier_frequency):
                 raise ValueError(msg)
 
             for info in carrier_frequency:
                 try:
-                    key, label, cf, cf_units = info
+                    key, cf, cf_units = info
                 except ValueError:
                     raise ValueError(msg)
 
-                # confirm that the key/label combination provided as input match the existing axis_property data
-                if self.axis_property.get_field(axis=key, name='label')[0] != label:
-                    raise ValueError('carrier frequency data does not match axes labels')
-
                 if cf_units.lower() == 'hz':
                     cf_hz = cf
                 elif cf_units.lower() == 'mhz':
                     cf_hz = cf * 1e6
                 else:
-                    raise ValueError(f'do not recognize units for carrier frequency: {cf_units}.   must use "Hz" or "MHz"')
+                    raise ValueError(f'do not recognize units for carrier frequency: {cf_units}.  must use "Hz" or "MHz"')
 
                 self.axis_property.set(
                     axis=key,
@@ -329,8 +333,10 @@ class PeakTable:
         """Use ppm peak positions and provided carrier frequencies to determine peak positions in Hz"""
 
         for axis in self.axis_keys():
+            dimension = self.axis2dimension(axis)
+
             try:
-                peak_ppm = self.get_par(par=f'{axis}_PPM')
+                peak_ppm = self.get_par(par=f'{dimension}_PPM')
             except KeyError:
                 raise KeyError(f'missing peak PPM data for axis: {axis}')
             try:
@@ -346,7 +352,7 @@ class PeakTable:
             except KeyError:
                 raise KeyError(f'missing carrier frequency for axis: {axis}')
             for idx, peak in enumerate(self.peaks):
-                peak.set_par(par=f'{axis}_HZ', value=peak_hz[idx])
+                peak.set_par(par=f'{dimension}_HZ', value=peak_hz[idx])
 
     def num_peaks(self):
         """
@@ -368,20 +374,20 @@ class PeakTable:
         except IndexError:
             raise IndexError('asking for index = {:d}, max index = {:d}'.format(index, len(self.peaks)))
 
-    def get_par(self, par, axis_keys='all'):
+    def get_par(self, par, axis_dimensions='all'):
         """
         Get all values for specified parameter for all peaks for specified axes.
 
         :param par: nmrPipe peak table parameter name (e.g. *_PPM, HEIGHT)
                     The * is substituted with axis values for each label requested
-        :param axis_keys: list of axis identifiers to include (e.g. 'X' or default of 'all')
+        :param axis_dimensions: list of axis identifiers to include (e.g. 'X' or default of 'all')
         :return: numpy array
         """
         out = []
         for peak in self.peaks:
             out.append(peak.get_par(
                 par=par,
-                axis_keys=axis_keys,
+                axis_dimensions=axis_dimensions,
             ))
         return np.array(out)
 
@@ -471,13 +477,16 @@ class PeakTable:
         """Number of dimensions"""
         return len(self.axis_keys())
 
-    def axis_labels(self):
-        """Get the axis labels"""
-        return self.axis_property.get_field(name='label')
+    def axis_dimensions(self):
+        """Get the axis dimensions"""
+        return self.axis_property.get_field(name='dimension')
 
-    def axis_keys_labels(self):
-        """Get a list of tuples where each contains an axis and its label"""
-        return [(ax, lab) for ax, lab in zip(self.axis_keys(), self.axis_labels())]
+    def axis2dimension(self, axis):
+        """Convert an axis (e.g. 'HN') to a dimension (e.g. 'X')"""
+        try:
+            return self.axis_property.get_field(name='dimension', axis=axis)[0]
+        except KeyError as e:
+            raise KeyError(e)
 
     def determine_outliers(self, chi2prob):
         # get full width of each recovered peak in points along each of its dimensions
@@ -573,11 +582,11 @@ class PeakTablePipe(PeakTable):
                                 # example: DATA  CLUSTER X_AXIS +/- 7
                                 continue
                             elif info[1].endswith('_AXIS'):
-                                axis = info[1].split('_')[0]
+                                axis = info[2]
                                 self.axis_property.set(
                                     axis=axis,
-                                    name='label',
-                                    value=info[2],
+                                    name='dimension',
+                                    value=info[1].split('_')[0],
                                 )
                                 self.axis_property.set(
                                     axis=axis,
@@ -693,10 +702,15 @@ class PeakTablePipeRec(PeakTablePipe):
 
 class PeakTablePipeInj(PeakTablePipe):
     """This subclass is for capturing the synthetic peaks "injected" by the NMRPipe genSimTab.tcl tool"""
-    def __init__(self, file, **kwargs):
+    def __init__(self, file, carrier_frequency, **kwargs):
         """
         :param carrier_frequency: either a list of values in MHz or an AxisData object (e.g. from another PeakTable)
         """
+
+        # could get carrier_frequency from kwargs input, but it wouldn't be a required input or autocomplete
+        # want to put carrier_frequency back into kwargs, so that kwargs can be passed up to super
+        kwargs['carrier_frequency'] = carrier_frequency
+
         # pre
         self.genSimTab = []
 
@@ -714,8 +728,9 @@ class PeakTablePipeInj(PeakTablePipe):
         # parse through the tokens to find maxLW values for each axis
         tokens = self.genSimTab.split()
         for axis in self.axis_keys():
+            dimension = self.axis2dimension(axis)
             try:
-                idx = tokens.index(f'-{axis.lower()}wMax')
+                idx = tokens.index(f'-{dimension.lower()}wMax')
                 self.axis_property.set(
                     axis=axis,
                     name='maxLW',
