@@ -1,6 +1,4 @@
 #!/usr/bin/env python3
-import time
-
 import copy
 import os
 import sys
@@ -12,7 +10,7 @@ from scipy.spatial import distance_matrix
 from itertools import combinations
 
 from nmrtoolbox.peak import PeakTable, PeakTablePipeRec, PeakTablePipeInj
-from nmrtoolbox.util import ROI, ParsePeakTableError, pairwise_weighted_norm
+from nmrtoolbox.util import ROI, ParsePeakTableError
 from nmrtoolbox.mask import Mask
 
 
@@ -44,8 +42,8 @@ class roc:
         :param height: keep all peaks with at least this HEIGHT
         :param abs_height: keep all peaks with absolute value at least this HEIGHT
         :param roi_list: region of interest to filter the recovered_peaklist
-            by in order to assess for corresponding synthetic peaks,
-            format is a list of [x_lower_bound_ppm, x_upper_bound_ppm, y_lower_bound_ppm, y_upper_bound_ppm, ...]
+            specified as a list of lists: [key, dimension, ppm1, ppm2]
+            example: [['HN', 'X', 10.297, 5.798], ['15N', 'Y', 129.088, 107.113]]
         :param index: keep only peaks with given index values
         :param cluster_type: keep only peaks with given cluster type index
             NMRPipe currently uses: 1 = Peak, 2 = Random Noise, 3 = Truncation artifact
@@ -92,18 +90,18 @@ class roc:
         # ================================================
         self.roi = None
         if roi_list is not None:
-            axis_labels = self.injected_peaks.axis_labels()
-            if len(roi_list) != 2*len(axis_labels):
-                raise ValueError('there should be a min and max value in ppm for each axis')
 
-            range_list = []
-            while roi_list:
-                range_list.append([roi_list.pop(0), roi_list.pop(0)])
+            try:
+                # capture the roi as temp object in case it is not good
+                roi_object = ROI(key_dimension_range=roi_list)
+            except ValueError as e:
+                raise ValueError(f'failed to read ROI - {e}')
 
-            self.roi = ROI(
-                axis_labels=axis_labels,
-                range_list=range_list,
-            )
+            if roi_object.axis_keys() != self.recovered_peaks.axis_keys():
+                raise ValueError('ROI axes do not match those of recovered peak table')
+
+            # after validation - capture the roi
+            self.roi = roi_object
 
         # ================================================
         self.mask = None
@@ -163,16 +161,14 @@ class roc:
 
     def _validate_input(self):
         # sometimes proton is labeled as 1H or HN, so standardize on the more common HN
-        if '1H' in self.recovered_peaks.axis_labels() and 'HN' in self.injected_peaks.axis_labels():
-            for axis, label in self.recovered_peaks.axis_keys_labels():
-                if label == '1H':
-                    self.recovered_peaks.axis[axis].label = 'HN'
+        if '1H' in self.recovered_peaks.axis_keys() and 'HN' in self.injected_peaks.axis_keys():
+            self.recovered_peaks.axis_property['HN'] = self.recovered_peaks.axis_property.pop('1H')
 
-        if self.injected_peaks.axis_labels() != self.recovered_peaks.axis_labels():
+        if self.injected_peaks.axis_keys() != self.recovered_peaks.axis_keys():
             raise ValueError('The injected and recovered peak tables have different axis labels.')
 
         if hasattr(self, 'roi'):
-            if self.injected_peaks.axis_labels() != self.roi.axis_labels():
+            if self.injected_peaks.axis_keys() != self.roi.axis_keys():
                 raise ValueError(
                     'The ROI definition does not have the same axis labels as the peak injected and recovered peak tables.')
 
@@ -310,7 +306,7 @@ class roc:
             n, bins, patches = ax.hist([p[dim] for p in peak_width_all], bins=20)
             ax.set_xlim(.9*np.min(bins), 1.1*np.max(bins))
             ax.set_ylim(-0.1*np.max(n), 1.1*np.max(n))
-            ax.set_title(self.recovered_peaks.axis_labels()[dim])
+            ax.set_title(self.recovered_peaks.axis_keys()[dim])
 
             # row 1: peak widths for KEEPERS on dimension
             ax = axs[1, dim]
@@ -385,8 +381,8 @@ class roc:
 
             fig, ax = plt.subplots()
             fig.subplots_adjust(right=0.75)
-            plt.xlabel(f"{self.recovered_peaks.axis_labels()[xdim]} Domain [ppm]")
-            plt.ylabel(f"{self.recovered_peaks.axis_labels()[ydim]} Domain [ppm]")
+            plt.xlabel(f"{self.recovered_peaks.axis_keys()[xdim]} Domain [ppm]")
+            plt.ylabel(f"{self.recovered_peaks.axis_keys()[ydim]} Domain [ppm]")
             plt.scatter(trueRecov_xdim_ppm, trueRecov_ydim_ppm,
                         c='#C5C9C7', marker='s', label='True Recovered')
             plt.scatter(falseRecov_xdim_ppm, falseRecov_ydim_ppm,
